@@ -31,11 +31,11 @@ use vars qw($VERSION @EXPORT @ISA
 use HTTP::Request::Common;
 use Text::ParseWords;
 
-$VERSION = '0.25';
+$VERSION = '0.26';
 
 ## these variables govern what type of quote the modules is retrieving
-$QURLbase = "http://download.finance.yahoo.com/d/quotes.csvr?e=.csv&f=";
-$QURLbase = "http://download.finance.yahoo.com/d/quotes.csv?e=.csv&f=";
+# $QURLbase = "http://download.finance.yahoo.com/d/quotes.csv?e=.csv&f=";
+$QURLbase = "https://download.finance.yahoo.com/d/quotes.csv?e=.csv&f=";
 $QURLformat = "snl1d1t1c1p2va2bapomwerr1dyj1x";	# default up to 0.19
 $QURLextended = "s7t8e7e8e9r6r7r5b4p6p5j4m3m4";	# new in 0.20
 $QURLrealtime = "b2b3k2k1c6m2j3"; # also new in 0.20
@@ -257,6 +257,10 @@ Finance::YahooQuote - Get stock quotes from Yahoo! Finance
 
 =head1 DESCRIPTION
 
+B<NOTE>: As of November 2017, the module is no longer all that useful
+as Yahoo! decided to halt the API service it relies on.
+
+
 This module gets stock quotes from Yahoo! Finance.  The B<getonequote>
 function will return a quote for a single stock symbol, while the
 B<getquote> function will return a quote for each of the stock symbols
